@@ -1,5 +1,4 @@
-"""
-Google API Python client library exec module.
+"""Google API Python client library exec module.
 
 Copyright (c) 2021-2022 VMware, Inc. All Rights Reserved.
 SPDX-License-Identifier: Apache-2.0
@@ -20,8 +19,8 @@ project.
 
 
 def __init__(hub):
-    """
-    Initializes this module.
+    """Initializes this module.
+
     :param hub: The Hub in which this Sub exists.
     """
     hub.exec.gcp_api.ACCT = ["gcp"]
