@@ -1,5 +1,4 @@
-"""
-Azure Resource Manager (ARM) Management exceptions module.
+"""Google Cloud Platform provider exceptions module.
 
 Copyright (c) 2021 VMware, Inc. All Rights Reserved.
 SPDX-License-Identifier: Apache-2.0
@@ -7,13 +6,11 @@ SPDX-License-Identifier: Apache-2.0
 
 
 class StateReturn(dict):
-    """
-    Convenience class to manage POP state returns.
-    """
+    """Convenience class to manage POP state returns."""
 
     def __init__(self, name=None, result=None, comment=None, old_obj={}, new_obj={}):
-        """
-        Initialize an object of this class.
+        """Initialize an object of this class.
+
         :param name: The name of the state (e.g. from a SLS file).
         :param result: True if the state call works, False otherwise.
         :param comment: Any relevant comments to the state execution.
