@@ -1,4 +1,4 @@
-"""State module for managing compute disks."""
+"""State module for managing Disks."""
 import copy
 from dataclasses import field
 from dataclasses import make_dataclass
@@ -357,7 +357,7 @@ async def present(
         resource_id = handle_operation_ret["resource_id"]
 
     if resource_id:
-        old_get_ret = await hub.exec.gcp_api.client.compute.disks.get(
+        old_get_ret = await hub.exec.gcp.compute.disks.get(
             ctx, name=name, resource_id=resource_id
         )
 
@@ -417,20 +417,6 @@ async def present(
         result["comment"].append(
             "No-op: There is no update function for gcp.compute.disks"
         )
-
-        # TODO [DA]: Call the separate update methods for disk properties.
-
-        # Steps to update each property in disks which are handled in specific functions
-        # 1. Add a comment about which properties are updatable
-        # 2. Check the parameter value and the old state value and mark if different
-        # 3. Call a specific update function which handles both run and test state
-        # 4. Example reference idem_aws/tool/aws/ec2/vpc_peering_connection_utils.py,
-        #    method update_vpc_peering_connection_options
-        # 5. If any of the updatable properties were updated or could have been,
-        #    update plan state and append an update comment
-        # 6. Follow the logic in compute/instances.py
-        # NOTE: Resource policies value format in old state does not match the one in plan state
-
     else:
         if ctx["test"]:
             result["comment"].append(
@@ -476,7 +462,7 @@ async def present(
     # Try getting the resource again
     # TODO: Reconciliation or waiter loop?
     # TODO: Check if this can be removed because insert and update may also return the necessary data on success
-    get_ret = await hub.exec.gcp_api.client.compute.disks.get(
+    get_ret = await hub.exec.gcp.compute.disks.get(
         ctx, name=name, resource_id=resource_id
     )
 
@@ -535,7 +521,7 @@ async def absent(
     """
     result = {
         "result": True,
-        "old_state": ctx.old_state,
+        "old_state": ctx.get("old_state"),
         "new_state": None,
         "name": name,
         "comment": [],
@@ -605,7 +591,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
     result = {}
 
-    describe_ret = await hub.exec.gcp_api.client.compute.disks.aggregatedList(
+    describe_ret = await hub.exec.gcp.compute.disks.list(
         ctx, project=ctx.acct.project_id
     )
 
@@ -613,7 +599,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         hub.log.debug(f"Could not describe disks {describe_ret['comment']}")
         return {}
 
-    for resource in describe_ret["ret"]["items"]:
+    for resource in describe_ret["ret"]:
         resource_id = resource.get("resource_id")
         result[resource_id] = {
             "gcp.compute.disks.present": [
