@@ -1,4 +1,4 @@
-"""State module for managing compute images."""
+"""State module for managing Images."""
 from dataclasses import field
 from dataclasses import make_dataclass
 from typing import Any
@@ -520,7 +520,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
     result = {}
 
-    describe_ret = await hub.exec.gcp_api.client.compute.images.aggregatedList(
+    describe_ret = await hub.exec.gcp.compute.images.list(
         ctx, project=ctx.acct.project_id
     )
 
@@ -528,7 +528,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         hub.log.debug(f"Could not describe images {describe_ret['comment']}")
         return {}
 
-    for resource in describe_ret["ret"]["items"]:
+    for resource in describe_ret["ret"]:
         resource_id = resource.get("resource_id")
         result[resource_id] = {
             "gcp.compute.images.present": [
