@@ -1,4 +1,4 @@
-"""State module for managing compute resource policies."""
+"""State module for managing Resource Policies."""
 from dataclasses import field
 from dataclasses import make_dataclass
 from typing import Any
@@ -423,17 +423,15 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
     result = {}
 
-    describe_ret = (
-        await hub.exec.gcp_api.client.compute.resource_policies.aggregatedList(
-            ctx, project=ctx.acct.project_id
-        )
+    describe_ret = await hub.exec.gcp.compute.resource_policies.list(
+        ctx, project=ctx.acct.project_id
     )
 
     if not describe_ret["result"]:
         hub.log.debug(f"Could not describe resource policies {describe_ret['comment']}")
         return {}
 
-    for resource in describe_ret["ret"]["items"]:
+    for resource in describe_ret["ret"]:
         resource_id = resource.get("resource_id")
         result[resource_id] = {
             "gcp.compute.resource_policies.present": [
