@@ -25,10 +25,6 @@ def delete_comment(hub, resource_type: str, name: str) -> str:
     return f"Deleted {resource_type} '{name}'"
 
 
-def delete_in_progress_comment(hub, resource_type: str, name: str) -> str:
-    return f"Bucket {resource_type} '{name}' delete in progress"
-
-
 def would_delete_comment(hub, resource_type: str, name: str) -> str:
     return f"Would delete {resource_type} '{name}'"
 
@@ -69,9 +65,19 @@ def non_updatable_properties_comment(
     return f"Forbidden modification of read-only properties: {str(non_updatable_properties)} for {resource_type} '{name}'"
 
 
-def resource_status_updated_comment(
-    hub, resource_type: str, name: str, new_status: str
+def update_property_comment(
+    hub, resource_type: str, resource_id: str, property_name: str, new_status: str
 ) -> str:
-    return (
-        f"The status of the {resource_type} with name - {name} is updated to {new_status}",
-    )
+    return f"Update property: {property_name} of resource type: {resource_type} with id: {resource_id} to value: {new_status}"
+
+
+def would_update_property_comment(
+    hub, resource_type: str, resource_id: str, property_name: str, new_status: str
+) -> str:
+    return f"Would update property: {property_name} of resource type: {resource_type} with id: {resource_id} to value: {new_status}"
+
+
+def ill_formed_resource_id_comment(
+    hub, resource_type: str, resource_id: str, reason: str
+) -> str:
+    return f"Ill-formed {resource_type} resource ID '{resource_id}': {reason}"
