@@ -1,5 +1,4 @@
-"""
-Idem plugin for the Google API Python client library.
+"""Idem plugin for the Google API Python client library.
 
 Google API Python client library
 :copyright: Copyright (c) 2020-2022 VMware, Inc. All Rights Reserved.
@@ -299,8 +298,9 @@ def __init__(hub):
 
 
 class _MemoryCache(base_cache.Cache):
-    """Class to cover for the lack of discovery client file_cache when
-    using recent oauth2client releases. See `Github commit
+    """Class to cover for the lack of discovery client file_cache when using recent oauth2client releases.
+
+    See `Github commit
     <https://github.com/GoogleCloudPlatform/python-docs-samples/commit/22788da481a8441500203ccc7fbf37cd9fcafa3b>`_.
     """
 
@@ -314,8 +314,7 @@ class _MemoryCache(base_cache.Cache):
 
 
 class _GCPApi:
-    """Class to represent (wrap) `Google's discovery based
-    APIs <https://github.com/googleapis/google-api-python-client>`_.
+    """Class to represent (wrap) `Google's discovery based APIs <https://github.com/googleapis/google-api-python-client>`_.
 
     Each instance represents a single service or (sub)resource in a way that
     enables writing code such as::
@@ -342,8 +341,7 @@ class _GCPApi:
     def __init__(
         self, hub, resource_type: str, parent=None, cache: base_cache.Cache = None
     ):
-        """
-        Initializes the instance.
+        """Initializes the instance.
 
         :param hub: The Idem hub to use for related calls (e.g., logging).
         :param resource_type: The name of the service or resource to wrap.
@@ -420,7 +418,6 @@ class _GCPApi:
         :return: The googleapiclient (client) resource.
         :rtype: _GCPApi
         """
-
         if attr == "wait_on_operations":
             return self.wait_on_operations
 
@@ -457,7 +454,6 @@ class _GCPApi:
         :return: The googleapiclient (client) resource.
         :rtype: _GCPApi
         """
-
         if self._parent is None:
             # Terminate the recursion at the top of the call tree:
             # the top of the tree is the cloud api object and has only
@@ -496,9 +492,7 @@ class _GCPApi:
             return self._api_resource
 
     def wait_on_operations(self, wait: bool):
-        """
-        Set this object instance to wait for the completion, or related error,
-        of all long running GCP API calls.
+        """Set this object instance to wait for the completion, or related error, of all long running GCP API calls.
 
         :param wait: Whether to wait (True) or not (False).
         """
