@@ -1,5 +1,4 @@
-"""
-Utilities for Google Cloud Platform APIs.
+"""Utilities for Google Cloud Platform APIs.
 
 Copyright (c) 2021-2022 VMware, Inc.
 SPDX-License-Identifier: Apache-2.0
@@ -21,8 +20,8 @@ def _is_empty(o) -> bool:
 
 
 def _is_within_dict(parent, o, ignore: set):
-    """
-    Determine of an object is within a parent dict object.
+    """Determine of an object is within a parent dict object.
+
     :param parent: The object in which o hopefully exists.
     :param o: The object to find in parent.
     :param ignore: A set of keys to ignore in parent.
@@ -50,8 +49,8 @@ def _is_within_dict(parent, o, ignore: set):
 
 
 def _is_within_list(parent, o, ignore: set):
-    """
-    Determine of an object is within a parent list object.
+    """Determine of an object is within a parent list object.
+
     :param parent: The object in which o hopefully exists.
     :param o: The object to find in parent.
     :param ignore: A set of keys to ignore in parent.
@@ -77,8 +76,8 @@ def _is_within_list(parent, o, ignore: set):
 
 
 def _is_within_set(parent, o, ignore: set):
-    """
-    Determine of an object is within a parent set object.
+    """Determine of an object is within a parent set object.
+
     :param parent: The object in which o hopefully exists.
     :param o: The object to find in parent.
     :param ignore: A set of keys to ignore in parent.
@@ -88,8 +87,8 @@ def _is_within_set(parent, o, ignore: set):
 
 
 def _is_within(parent, o, ignore: set):
-    """
-    Determine of an object is within a parent object.
+    """Determine of an object is within a parent object.
+
     :param parent: The object in which o hopefully exists.
     :param o: The object to find in parent.
     :param ignore: A set of keys to ignore in parent.
@@ -112,9 +111,8 @@ def _is_within(parent, o, ignore: set):
 
 
 def is_within(hub, parent, o, ignore: set = {}):
-    """
-    Returns True if the object (o) is contained within parent (top level)
-    object.
+    """Returns True if the object (o) is contained within parent (top level) object.
+
     :param hub: The redistributed pop central hub. This is required in
     Idem, so while not used, must appear.
     :param parent: The object to check if contains o.
@@ -149,9 +147,9 @@ def _merge_dicts(target: Dict, source: Dict) -> Dict:
 
 
 def merge_dicts(hub, target: dict, source: dict) -> dict:
-    """
-    Returns the dict resulting from overwriting values within a source dict
-    into a target dict, recursively. All values within a key from the source
+    """Returns the dict resulting from overwriting values within a source dict into a target dict, recursively.
+
+    All values within a key from the source
     will overwrite the same within the target. For example, consider the
     following merged result:
 
@@ -170,9 +168,9 @@ def merge_dicts(hub, target: dict, source: dict) -> dict:
     return _merge_dicts(result, source)
 
 
-def has_changes(
+def compare_states(
     hub, old_state: Dict, plan_state: Dict, resource_type: str = None
-) -> bool:
+) -> Dict:
     exclude_paths = []
 
     for key in old_state.keys():
